==> openshift-client-5.4.1-sources.jar: io/fabric8/openshift/client/handlers/operator/KubeStorageVersionMigratorHandler.java <==

                                                    

package io.fabric8.openshift.client.handlers.operator;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.operator.KubeStorageVersionMigratorOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.operator.v1.KubeStorageVersionMigrator;
import io.fabric8.openshift.api.model.operator.v1.KubeStorageVersionMigratorBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class KubeStorageVersionMigratorHandler implements ResourceHandler<KubeStorageVersionMigrator, KubeStorageVersionMigratorBuilder> {

  @Override
  public String getKind() {
    return KubeStorageVersionMigrator.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public KubeStorageVersionMigrator create(OkHttpClient client, Config config, String namespace, KubeStorageVersionMigrator item, boolean dryRun) {
    return new KubeStorageVersionMigratorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public KubeStorageVersionMigrator replace(OkHttpClient client, Config config, String namespace, KubeStorageVersionMigrator item, boolean dryRun) {
    return new KubeStorageVersionMigratorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public KubeStorageVersionMigrator reload(OkHttpClient client, Config config, String namespace, KubeStorageVersionMigrator item) {
    return new KubeStorageVersionMigratorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public KubeStorageVersionMigratorBuilder edit(KubeStorageVersionMigrator item) {
    return new KubeStorageVersionMigratorBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, KubeStorageVersionMigrator item, boolean dryRun) {
    return new KubeStorageVersionMigratorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, KubeStorageVersionMigrator item, Watcher<KubeStorageVersionMigrator> watcher) {
    return new KubeStorageVersionMigratorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, KubeStorageVersionMigrator item, String resourceVersion, Watcher<KubeStorageVersionMigrator> watcher) {
    return new KubeStorageVersionMigratorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, KubeStorageVersionMigrator item, ListOptions options, Watcher<KubeStorageVersionMigrator> watcher) {
  return new KubeStorageVersionMigratorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public KubeStorageVersionMigrator waitUntilReady(OkHttpClient client, Config config, String namespace, KubeStorageVersionMigrator item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new KubeStorageVersionMigratorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public KubeStorageVersionMigrator waitUntilCondition(OkHttpClient client, Config config, String namespace, KubeStorageVersionMigrator item, Predicate<KubeStorageVersionMigrator> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new KubeStorageVersionMigratorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.6.0-sources.jar: io/fabric8/openshift/client/handlers/operator/KubeStorageVersionMigratorHandler.java <==

                                                    

package io.fabric8.openshift.client.handlers.operator;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.openshift.client.dsl.internal.operator.KubeStorageVersionMigratorOperationsImpl;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.KubeStorageVersionMigrator;
import io.fabric8.openshift.api.model.operator.v1.KubeStorageVersionMigratorBuilder;

public class KubeStorageVersionMigratorHandler implements ResourceHandler<KubeStorageVersionMigrator, KubeStorageVersionMigratorBuilder> {

  @Override
  public String getKind() {
    return KubeStorageVersionMigrator.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "operator.openshift.io/v1";
    }

  @Override
  public KubeStorageVersionMigratorBuilder edit(KubeStorageVersionMigrator item) {
    return new KubeStorageVersionMigratorBuilder(item);
  }

  @Override
  public Resource<KubeStorageVersionMigrator> resource(OkHttpClient client, Config config, String namespace, KubeStorageVersionMigrator item) {
    return new KubeStorageVersionMigratorOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName());
  }

}
